@@ -88,7 +88,10 @@ class CommandExecutor():
 
     def close(self):
         if self.child is not None:
-            self.child.close()
+            try:
+                self.child.close()
+            except pexpect.ExceptionPexpect:
+                self.child.close(force=True)
             self.child = None
 
     def success(self):
